@@ -39,7 +39,6 @@ class QDomDocument;
 class ClientStream;
 class KNetworkConnector;
 class Task;
-class KTemporaryFile;
 struct YABEntry;
 
 namespace KYahoo {
@@ -165,7 +164,7 @@ Q_OBJECT
 		 * @param group the group where the buddy will be placed
 		 * @param message the message that will be sent to the buddy along the authorization request
 		 */
-		void addBuddy( const QString &userId, const QString &group, const QString &message = QLatin1String("Please add me")  );
+		void addBuddy( const QString &userId, const QString &group, const QString &message = QStringLiteral("Please add me")  );
 
 		/**
 		 * Remove a buddy from the contact list
@@ -464,7 +463,7 @@ Q_OBJECT
 		 */
 		void notifyError( const QString &info, const QString &errorString, LogLevel level );
 
-	signals:
+	Q_SIGNALS:
 		/** CONNECTION EVENTS */
 		/**
 		 * Notifies that the login process has succeeded.
@@ -687,7 +686,7 @@ Q_OBJECT
 		 * We have received a message in a chatroom
 		 */
 		void chatMessageReceived( const QString &, const QString &, const QString & );
-	protected slots:
+	protected Q_SLOTS:
 		// INTERNAL, FOR USE BY TASKS' finished() SIGNALS //
 		void lt_loginFinished();
 		void lt_gotSessionID( uint );
