@@ -31,16 +31,16 @@
 #include <QLatin1String>
 
 // KDE Includes
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include "yahoo_protocol_debug.h"
 #include <kmessagebox.h>
 #include <krun.h>
 #include <kurl.h>
-#include <kfiledialog.h>
 #include <kpassworddialog.h>
 #include <kconfig.h>
-#include <kstandarddirs.h>
+
 #include <ktoolinvocation.h>
+#include <kmessagebox_queued.h>
 
 // Kopete Includes
 #include <addcontactpage.h>
@@ -55,7 +55,7 @@
 YahooEditAccount::YahooEditAccount(YahooProtocol *protocol, Kopete::Account *theAccount, QWidget *parent): QWidget(parent), KopeteEditAccountWidget(theAccount)
 {
 	setupUi(this);
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	theProtocol = protocol;
 
@@ -67,7 +67,7 @@ YahooEditAccount::YahooEditAccount(YahooProtocol *protocol, Kopete::Account *the
 
 		QString pagerServer = account()->configGroup()->readEntry("Server", "scsa.msg.yahoo.com");
 		int pagerPort = account()->configGroup()->readEntry("Port", 5050);
-		if( pagerServer != "scsa.msg.yahoo.com" || pagerPort != 5050 )
+		if( pagerServer != QLatin1String("scsa.msg.yahoo.com") || pagerPort != 5050 )
 			optionOverrideServer->setChecked( true );
 		else
 			optionOverrideServer->setChecked( false );
@@ -94,22 +94,25 @@ YahooEditAccount::YahooEditAccount(YahooProtocol *protocol, Kopete::Account *the
 	QWidget::setTabOrder( mScreenName, mPasswordWidget->mRemembered );
 	QWidget::setTabOrder( mPasswordWidget->mRemembered, mPasswordWidget->mPassword );
 	QWidget::setTabOrder( mPasswordWidget->mPassword, mAutoConnect );
+    if (parent && parent->layout()) {
+        parent->layout()->addWidget(this);
+    }
 
 	show();
 }
 
 bool YahooEditAccount::validateData()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	if(mScreenName->text().isEmpty())
-	{	KMessageBox::queuedMessageBox(this, KMessageBox::Sorry,
-			i18n("<qt>You must enter a valid screen name.</qt>"), i18n("Yahoo"));
+    {
+        KMessageBox::queuedMessageBox(this, KMessageBox::Sorry,	i18n("<qt>You must enter a valid screen name.</qt>"), i18n("Yahoo"));
 		return false;
 	}
 	if(!mPasswordWidget->validate())
-	{	KMessageBox::queuedMessageBox(this, KMessageBox::Sorry,
-			i18n("<qt>You must enter a valid password.</qt>"), i18n("Yahoo"));
+    {
+        KMessageBox::queuedMessageBox(this, KMessageBox::Sorry,	i18n("<qt>You must enter a valid password.</qt>"), i18n("Yahoo"));
 		return false;
 	}
 	return true;
@@ -117,7 +120,7 @@ bool YahooEditAccount::validateData()
 
 Kopete::Account *YahooEditAccount::apply()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	if ( !account() )
 		setAccount( new YahooAccount( theProtocol, mScreenName->text().toLower() ) );
@@ -135,7 +138,7 @@ Kopete::Account *YahooEditAccount::apply()
 	}
 	else
 	{
-		yahooAccount->setServer( "scsa.msg.yahoo.com" );
+		yahooAccount->setServer( QStringLiteral("scsa.msg.yahoo.com") );
 		yahooAccount->setPort( 5050 );
 	}
 
@@ -155,7 +158,7 @@ Kopete::Account *YahooEditAccount::apply()
 
 void YahooEditAccount::slotOpenRegister()
 {
-	KToolInvocation::invokeBrowser( QLatin1String("http://edit.yahoo.com/config/eval_register?new=1") );
+	KToolInvocation::invokeBrowser( QStringLiteral("http://edit.yahoo.com/config/eval_register?new=1") );
 }
 
 void YahooEditAccount::slotSelectPicture()
@@ -170,12 +173,8 @@ void YahooEditAccount::slotSelectPicture()
 	}
 	else
 	{
-		KMessageBox::queuedMessageBox( this, KMessageBox::Sorry, i18n( "<qt>The selected buddy icon could not be opened. <br />Please set a new buddy icon.</qt>" ), i18n( "Yahoo Plugin" ) );
+        KMessageBox::queuedMessageBox( this, KMessageBox::Sorry, i18n( "<qt>The selected buddy icon could not be opened. <br />Please set a new buddy icon.</qt>" ), i18n( "Yahoo Plugin" ) );
 		return;
 	}
 }
 
-#include "yahooeditaccount.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
-
